@@ -7,20 +7,23 @@
 # https://github.com/manatlan/htbulma
 # #############################################################################
 
-from . import TagBulma,Slider,InputText
+from . import TagBulma
 from htag import Tag
 import json
 
 class Form(Tag.form):
     def __init__(self,onsubmit=None,**a):
         Tag.__init__(self,**a)
-        self["onsubmit"]="%s;event.preventDefault();" % self.bind._onsubmit(b"JSON.stringify(Object.fromEntries(new FormData(this)))")
-        self.onsubmit = onsubmit
+        # rewrite the form.submit() (bicoz this method doesn't call the onsubmit ;-( )
+        self.js = """tag.submit=function() {%s}""" % self.bind._onsubmit(b"JSON.stringify(Object.fromEntries(new FormData(this)))")
+
+        self["onsubmit"]="event.preventDefault();this.submit()"
+        self._callback = onsubmit
 
     @Tag.NoRender # avoid redrawing itself
-    def _onsubmit(self,f):
-        if self.onsubmit:
-            self.onsubmit(json.loads(f))
+    def _onsubmit(self,f:dict):
+        if self._callback:
+            self._callback(json.loads(f))
 
 
 if __name__=="__main__":
@@ -28,9 +31,9 @@ if __name__=="__main__":
         print(form)
 
     obj=Form(onsubmit=onsubmit)
-    obj<=InputText("",_name="txt")
-    obj<=Tag.H.input(_name="txt2",_value="", _class="input")
-    obj<=Slider(1,1,100,_name="sel")
+    obj<=Tag.H.input(_name="txt1",_value="1", _class="input")
+    obj<=Tag.H.input(_name="txt2",_value="2", _class="input")
+    obj<=Tag.H.input(_name="txt3",_value="3", _class="input")
     obj<=Tag.H.input(_type="submit",_value="ok", _class="button")
 
     from . import _test
